Package: prodest
Type: Package
Title: Production Function Estimation
Version: 1.0.1
Author: Gabriele Rovigatti [aut,cre]
Maintainer: Gabriele Rovigatti <gabriele.rovigatti@gmail.com>
Description: Implements the methods proposed by Olley, G.S. and Pakes, A. (1996) <doi:10.2307/2171831>, Levinsohn, J. and Petrin, A. (2003) <doi:10.1111/1467-937X.00246>, Ackerberg, D.A. and Caves, K. and Frazer, G. (2015) <doi:10.3982/ECTA13408> and Wooldridge, J.M. (2009) <doi:10.1016/j.econlet.2009.04.026> for structural productivity estimation .
License: GPL-3
BugReports: https://github.com/GabrieleRovigatti/prodest/issues
URL: https://github.com/GabrieleRovigatti/prodest/tree/master/prodest
LazyData: TRUE
Depends: R (>= 2.10), dplyr, parallel, Matrix, methods
Imports: Rsolnp, DEoptim, AER
Suggests: testthat
Repository: CRAN
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2018-06-19 13:10:04 UTC; gabriele
Date/Publication: 2018-06-19 13:21:32 UTC
Built: R 4.6.0; ; 2026-05-01 02:14:13 UTC; unix
