Package: prodest
Type: Package
Title: Production Function Estimation
Version: 1.0.2
Authors@R: person(given = "Gabriele",
                  family = "Rovigatti",
                  role = c("aut", "cre"),
                  email = "gabriele.rovigatti@gmail.com")
Description: Implements the methods proposed by Olley, G.S. and Pakes, A. (1996) <doi:10.2307/2171831>, Levinsohn, J. and Petrin, A. (2003) <doi:10.1111/1467-937X.00246>, Ackerberg, D.A. and Caves, K. and Frazer, G. (2015) <doi:10.3982/ECTA13408> and Wooldridge, J.M. (2009) <doi:10.1016/j.econlet.2009.04.026> for structural productivity estimation.
License: GPL-3
BugReports: https://github.com/GabrieleRovigatti/prodest/issues
URL: https://github.com/GabrieleRovigatti/prodest
LazyData: TRUE
Depends: R (>= 2.10), dplyr, parallel, Matrix, methods
Imports: Rsolnp, DEoptim, AER
Suggests: testthat
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2026-09-01 14:25:47 UTC; m031421
Author: Gabriele Rovigatti [aut, cre]
Maintainer: Gabriele Rovigatti <gabriele.rovigatti@gmail.com>
Repository: CRAN
Date/Publication: 2026-09-01 15:20:02 UTC
