#exportPattern("^[[:alpha:]]+")
import("methods")
import("DEoptim")
importFrom("Rsolnp", "solnp")
import("dplyr")
importFrom("AER", "ivreg")
importFrom("parallel", "clusterEvalQ", "parLapply")
importFrom("Matrix", "bdiag")
importFrom("stats", "fitted", "lm", "model.frame", "model.matrix",
     "na.exclude", "optim", "resid", "rnorm", "runif", "sd",
     "var", "binomial", "glm", "lm.fit", "predict")
exportClasses("prod")
exportMethods("coef","omega","FSres","summary","show")
export("coef","omega","FSres")
export("prodestOP","prodestLP","prodestACF","prodestWRDG","prodestWRDG_GMM","panelSim","prodestROB")
export("printProd")
export("gOPLP","gACF","finalOPLP","finalACF")
export("checkM", "checkMD","lagPanel","block.boot.resample","weightM","withinvar")
