# prodest
Production Function Estimation in R

`prodest` ([Rovigatti, 2017]) implements most of the methods for production function estimation. The prodest package provides 
functions to simulate panel data,
estimate the productivity, state and free variables parameters. Full description of the models, their issues and characteristics
is available in [Mollisi et al., 2017](https://papers.ssrn.com/sol3/papers.cfm?abstract_id=2916753).

The latest stable version of `prodest` is available at 'https://CRAN.R-project.org/package=prodest'.

The latest development version of `prodest` is available at 'https://github.com/GabrieleRovigatti/prodest'.

Please cite `prodest` in publications:

Rovigatti, G. (2026).  
_prodest: Production Function Estimation_.  
R package version 1.0.2.

Rovigatti, G. (2017).  
Production Function Estimation in R: The prodest Package.  
_Journal of Open Source Software_, 2(18), 371.  
https://doi.org/10.21105/joss.00371  
 